% comp_freq_resp() - making BOLD-image like plot to show frequency
%                    response of either ROA+ raw mean time course
%                    or back-projected component time course of
%                    each component. This function can help to
%                    cluster the components in freq. domain.
%
% Usage:
%   >> comp_freq_resp(tc, cri);
%
% Inputs: 
%   tc = the time course used to yield the freq. resp 
%        0: ROA+ raw mean time couese (default)
%        1: back-projected component time course
%   cri = string variable containing criterion to select the ROA
%        e.g., '> 0.95' (default is in percentile unit)
%
% Output: 
%
% Author: 
%   Jeng-Ren Duann, SCCN/INC/UCSD and CNL/Salk Inst. 2004-05
%
% See also: psd(),
%
% Notes:
%

% --
% Copyright (C) 2004 Jeng-Ren Duann, Salk Institute, duann@salk.edu
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License as
% published by the Free Software Foundation; either version 2 of
% the License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

function comp_freq_resp(tc)
  
global FMRI

% deal with the default setting
if nargin < 2,
  cri = '> 0.95';
end
if nargin < 1,
  tc = 0;
end

W = FMRI.icaweight * FMRI.icasphere;
u = W * FMRI.data;

% determining fft length
a = ceil(log2(FMRI.timepoint));
fft_len = 2^a;
comp_no = size(FMRI.icaweight,1);
ff = zeros(comp_no,1+fft_len/2);

figure
for comp = 1:comp_no; % for loop starts here
  temp = u(comp,:);
  [h,x] = hist(temp,1000);

  % finding the threshold of component activity
  sum_h = 0;
  for i=1:1000,
    sum_h = sum_h + h(i);
    a = sum_h/sum(h);
    if eval(['a ' cri]),
      break;
    end
  end
  thre = x(i);
  idx = find(temp >= thre);
  
  if tc==0, % using ROA+ raw mean time course
    tt = mean(FMRI.data(:,idx)');
  else % using back-projected component time course
    invW = pinv(W);
    u2 = zeros(size(u));
    u2(comp,:) = u(comp,:);
    data2 = invW * u2;
    tt = mean(data2(:,idx)');
  end
  
  tt = tt-mean(tt);
  
  % calculating psd for each time course
  [p,f] = psd(tt,fft_len,1/FMRI.tr);
  ff(comp,:) = p'/max(p);
  disp(['Component #' int2str(comp) ' finished ...']);
end

imagesc(ff);
a = get(gca,'xtick');
set(gca,'xticklabel',f(a));