% roa_complexity() - measure the complexity of the component ROA
%
% Usage:
%   >> c = roa_complexity(comp);
%
% Inputs:
%   comp - component number (can be an row array indicating
%          multiple components)
%
% Outputs:
%   c - complexity measurement(s)
%
% Author: Jeng-Ren Duann, SCCN/INC/UCSD & CNL/Salk Inst. 2004
%
% See also: map_on_fmri3(), map_on_struc3()
%
% Notes: - The complexity is measured by the map complexity, which
% measuring the turn-over rate of the binary ROA map
 
% --
% Copyright (C) 2004 Jeng-Ren Duann, INC/UCSD, 2004
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License as
% published by the Free Software Foundation; either version 2 of
% the License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

% $Log: roa_complexity.m,v $
%


function c = roa_complexity(comp)
  
  global FMRI

  if max(comp) > size(FMRI.icaweight,1),
    fmrlab_messagedlg('ROA Complexity',...
		      'Error',...
		      'Maximum input comp. > no. of ICs',...
		      {'OK'});
    c = 0;
    return;
  end
  
  W = FMRI.icaweight * FMRI.icasphere;
  u = W * FMRI.data;
  
  c = zeros(1,length(comp));
  for ii = 1:length(comp),
    temp = u(comp(ii),:);
    temp = (temp-mean(temp))/std(temp);
    idx = find(abs(temp)>1.5);
    temp2 = zeros(size(temp));
    temp2(idx) = 1;
    temp = zeros(1,FMRI.dime_x*FMRI.dime_y*FMRI.dime_z);
    for jj=1:length(FMRI.idx),
      temp(FMRI.idx(jj)) = temp2(jj);
    end
    temp = reshape(temp,FMRI.dime_x,FMRI.dime_y,FMRI.dime_z);
    y_temp = zeros(FMRI.dime_y,FMRI.dime_x,FMRI.dime_z);
    % flip the even-number rows for turn-over rate measure
    for jj=1:FMRI.dime_z,
      % calculate complexity in x-direction
      temp2 = temp(:,:,jj);
      temp2 = squeeze(temp2);
      temp2(2:2:FMRI.dime_x,:) = fliplr(temp2(2:2:FMRI.dime_x,:));
      temp(:,:,jj) = temp2;
      
      % calculate complexity in y-direction
      temp3 = temp(:,:,jj);
      temp3 = squeeze(temp3)';
      temp3(2:2:FMRI.dime_y,:) = fliplr(temp3(2:2:FMRI.dime_y,:));
      y_temp(:,:,jj) = temp3;
    end
    temp = temp(:)';
    y_temp = y_temp(:)';
    
    % measure turn-over rate
    idx = find(diff(temp) ~= 0);
    y_idx = find(diff(y_temp) ~= 0);
    c(ii) = sqrt(length(y_idx)^2+length(idx)^2)/length(temp);
  end
  